
# THIS FILE IS GENERATED FROM syned SETUP.PY
short_version = '1.0.16'
version = '1.0.16'
full_version = '1.0.16.dev0+b853dd9'
git_revision = 'b853dd9bd80443a2800c076724b5138725072b6c'
release = False

if not release:
    version = full_version
    short_version += ".dev"
